@@ -1,5 +1,4 @@
-# (C) Copyright 2020 ECMWF.
-#
+# (C) Copyright 2020 ECMWF.  #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
@@ -7,6 +6,5 @@
 # nor does it submit to any jurisdiction.
 #
 
-from .docstring import docstring
-
-__all__ = ["docstring"]
+# This empty __init__.py is there to help find_packages() (in setup.py)
+# to include this folder in the tar uploaded at pip
