@@ -62,9 +62,6 @@ SAMPLES = [
 
 
 class HighLow(Dataset):
-    def __init__(self):
-        pass
-
     def _load(self, **req):
         self._fields = []
         for date, area, label in SAMPLES:
