@@ -10,7 +10,6 @@
 #
 
 import os
-import sys
 
 import pytest
 
@@ -22,7 +21,6 @@ def test_dataset_1():
     load_dataset("sample-bufr-data")
 
 
-@pytest.mark.skipif(sys.version_info < (3, 7), reason="Version 3.7 or greater needed")
 def test_dataset_2():
     dataset.sample_bufr_data()
 
@@ -31,9 +29,7 @@ def test_era5_temperature():
     if not os.path.exists(os.path.expanduser("~/.cdsapirc")):
         pytest.skip("No ~/.cdsapirc")
 
-    ds = cml.load_dataset(
-        "era5-temperature", period=(1979, 1982), domain="France", time=12
-    )
+    cml.load_dataset("era5-temperature", period=(1979, 1982), domain="France", time=12)
 
 
 def test_datetime():
@@ -55,7 +51,7 @@ def test_pandas_filter():
 
 
 if __name__ == "__main__":
-    test_datetime()
-
-if __name__ == "__main__":
-    test_dataset_1()
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
