@@ -78,4 +78,7 @@ def test_multi():
 
 
 if __name__ == "__main__":
-    test_multi()
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
